betty.plugin.entry_point module - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.plugin.entry_point module

Integrates the plugin API with distribution packages.

Read more at Entry point plugins.

final class betty.plugin.entry_point.EntryPointPluginRepository

  Bases: `LazyPluginRepositoryBase`[`_PluginT`], `Generic`[`_PluginT`]

  Discover plugins defined as distribution package entry points.

  __init__(entry_point_group: str)